#!/bin/bash -e

#
# containerRestore.sh
#
# Effettua il rirpistino del container che eroga il servizio
#

#
# Parametri
#
# caller:		nome dello script chiamante
# container:    identificativo del container che eroga il servizio
# containerBackupAbsolutePath:
#               path assoluto del file per il backup del container
# logFilePath:  path del file di log per il backup
#

########################################################################
#
# Predispone l'ambiente di esecuzione
#

#
# Attenzione!!!!
#    la variabile pmxBackupRestorePath e' valorizzata all'interno
#    del file /etc/profile
#

# Importa la definizione delle costanti simboliche
source $pmxBackupRestorePath/scripts/symbolicConstantsSetup.sh

# Importa la definizione delle utilities
source $UTILITIES

# Importa la definizione dei messaggi di log
source $LOG_MESSAGES
#
########################################################################

# Controlla che il numero dei parametri sia corretto
checkParams $# 4 "$(dateTime) $msgIncorrectParameterNumber \
                              <caller> \ 
                              <container> \
                              <containerBackupAbsolutePath> \
                              <logFilePath>"

# Inizializza le variabili mnemoniche per i parametri          
caller=$1
container=$2	
containerBackupAbsolutePath=$3
logFilePath=$4

# Traccia l'ingresso nello script
appendToLog "$(dateTime) $msgIntoTheScript" \
            "$logFilePath"
            
echo "caller: $caller"
echo "container: $container"
echo "containerBackupAbsolutePath: $containerBackupAbsolutePath"
echo "logFilePath: $logFilePath"
            
# Traccia il chiamante lo script
appendToLog "$(dateTime) $msgScriptCaller $caller" \
            "$logFilePath"

# ripristina il container a partire dal suo backup      
# pct restore <nro_container> <path_assoluto_del backup container> --storage local-lvm
# echo pct restore $container $containerBackupAbsolutePath --storage local-lvm
pct restore 210 $containerBackupAbsolutePath --storage local-lvm

# Traccia l'uscita dallo script
appendToLog "$(dateTime) $msgOutOfTheScript" \
            "$logFilePath"
exit
